-- 3 Possibilities for Addresses:
-- a) 2 views or tables in an external database/scheme with the following columns:
--    a1) STREET_NAME, STREET_ID
--    a2) ADR_X, ADR_Y, STREET_NUMBER, OBJECT_ID, OBJ_X, OBJ_Y, STREET_NAME, STREET_ID
--    and the synonyms GIS_V_STREETS and GIS_V_OBJECTADRESS refering to them.
-- b) 2 views in the CITYMAN-scheme with the columns as above viewing to external tables
--    and the synonyms GIS_V_STREETS and GIS_V_OBJECTADRESS refering to them.
-- c) 2 tables in the CITYMAN-scheme with the columns as above
--    and the synonyms GIS_V_STREETS and GIS_V_OBJECTADRESS refering to them.
-- Variante (c) is installed per default (with table names STREET_TEMPLATE and ADDRESS_TEMPLATE)
-- and can be changed interactively afterwards.

-- The Following two views are only as template for variante (b)

CREATE OR REPLACE VIEW "V_ADDRESS" ("ADR_X",
		"ADR_Y","STREET_NUMBER","OBJECT_ID","OBJ_X","OBJ_Y",
		"STREET_NAME","STREET_ID") AS 
	select ADDRESS_TEMPLATE.ADR_X, ADDRESS_TEMPLATE.ADR_Y, 
	ADDRESS_TEMPLATE.STREET_NUMBER, ADDRESS_TEMPLATE.OBJECT_ID, 
	ADDRESS_TEMPLATE.OBJ_X, ADDRESS_TEMPLATE.OBJ_Y, 
	STREET_TEMPLATE.NAME as STREET_NAME,
	STREET_TEMPLATE.STREET_KEY as STREET_ID 
	from ADDRESS_TEMPLATE, STREET_TEMPLATE 
	WHERE ( ADDRESS_TEMPLATE.STREET_KEY = STREET_TEMPLATE.STREET_KEY )
	WITH READ ONLY
/

CREATE OR REPLACE VIEW "V_STREET" ("STREET_NAME", "STREET_ID") AS 
	select NAME as STREET_NAME, STREET_KEY as STREET_ID 
	from STREET_TEMPLATE WITH READ ONLY
/

-- The following views are obligatory! They use the synonym GIS_V_OBJECTADRESS

create or replace view V_GIS_MODELOBJECTS as 
	select MODELUNIT.MODEL, UNIT.UNIT, UNIT_NUMBER, UNITID, UNIT.NAMEN, GIS_V_OBJECTADRESS.STREET_NAME, GIS_V_OBJECTADRESS.STREET_NUMBER, GIS_V_OBJECTADRESS.OBJECT_ID, UNITGIS.STREET_NUMBER_INT 
	from MODELUNIT, UNIT, UNITGIS, GIS_V_OBJECTADRESS 
	where ( ( UNIT.UNIT = MODELUNIT.UNIT ) and ( UNITGIS.UNIT = UNIT.UNIT ) and ( GIS_V_OBJECTADRESS.OBJECT_ID = UNITGIS.GISKEY ) );
/

create or replace view "V_GIS_OBJECTS" as	
	select UNIT.UNIT, UNIT_NUMBER, UNITID, GIS_V_OBJECTADRESS.STREET_NAME, UNIT.NAMEN
	from UNIT, UNITGIS, GIS_V_OBJECTADRESS
	where ( UNITGIS.UNIT = UNIT.UNIT and GIS_V_OBJECTADRESS.OBJECT_ID = UNITGIS.GISKEY );
/

-- views fr die letzte gltige/stabile Versionsnummer
create or replace view "V_LAST_VALID_VERSIONNUMBER" as	
	select UNITVERSION.UNIT, max(UNITVERSION.VERSIONNUMBER) as VERSIONNUMBER
	from UNITVERSION
	where UNITVERSION.STATE <> 3
	group by UNITVERSION.UNIT;
/
	
create or replace view "V_LAST_STABLE_VERSIONNUMBER" as	
	select UNITVERSION.UNIT, max(UNITVERSION.VERSIONNUMBER) as VERSIONNUMBER
	from UNITVERSION
	where UNITVERSION.STATE <> 2 and UNITVERSION.STATE <> 3
	group by UNITVERSION.UNIT;
/

-- new views in schema 2.6
create or replace view V_LAST_VALID_VERSION as 
	select UNITVERSION.UNITVERSION, UNITVERSION.VERSIONNUMBER, UNITVERSION.VERSIONDATE, UNITVERSION.UNIT, UNITVERSION.STATE, UNITVERSION."COMMENT" 
	from UNITVERSION, V_LAST_VALID_VERSIONNUMBER 
	where UNITVERSION.UNIT=V_LAST_VALID_VERSIONNUMBER.UNIT 
	and UNITVERSION.VERSIONNUMBER=V_LAST_VALID_VERSIONNUMBER.VERSIONNUMBER;
/

create or replace view V_LAST_STABLE_VERSION as 
	select UNITVERSION.UNITVERSION, UNITVERSION.VERSIONNUMBER, UNITVERSION.VERSIONDATE, UNITVERSION.UNIT, UNITVERSION.STATE, UNITVERSION."COMMENT" 
	from UNITVERSION, V_LAST_STABLE_VERSIONNUMBER 
	where UNITVERSION.UNIT=V_LAST_STABLE_VERSIONNUMBER.UNIT 
	and UNITVERSION.VERSIONNUMBER=V_LAST_STABLE_VERSIONNUMBER.VERSIONNUMBER;
/

-- new version in Schema 2.7
create or replace view V_MODEL_TEXTURE_IMAGE as 
	select distinct MODELUNIT.MODEL, IMAGE.IMAGE 
	from MODELUNIT, V_LAST_STABLE_VERSION, OBJECT, ELEMENTCOMPLEX, ELEMENT, TEXTURE, IMAGE 
	where 
		V_LAST_STABLE_VERSION.UNIT = MODELUNIT.UNIT and 
		OBJECT.UNITVERSION = V_LAST_STABLE_VERSION.UNITVERSION and 
		ELEMENTCOMPLEX.OBJECT = OBJECT.OBJECT and 
		ELEMENT.ELEMENTCOMPLEX = ELEMENTCOMPLEX.ELEMENTCOMPLEX and 
		TEXTURE.ELEMENT = ELEMENT.ELEMENT and 
		IMAGE.IMAGE = TEXTURE.IMAGE;
/

create or replace view "V_MODELUNITS" as
	select MODEL.NAMEN as MODEL_NAMEN, UNIT.NAMEN
    as UNIT_NAMEN, UNIT.UNIT_NUMBER, UNIT.UNITID, MODELUNIT.MODEL, MODELUNIT.UNIT
    from MODEL, UNIT, MODELUNIT
    where ( ( MODELUNIT.MODEL = MODEL.MODEL ) and ( UNIT.UNIT = MODELUNIT.UNIT ) );
/

CREATE OR REPLACE VIEW "V_UNITEXPORT" ("DATA","NAMEN",
    "MODEL","UNIT","EXPORTDATA","LOD","TYPE") AS 
    select EXPORTDATA.DATA, MODEL.NAMEN, 
    MODELUNIT.MODEL, MODELUNIT.UNIT, UNITEXPORT.
    EXPORTDATA, UNITEXPORT.LOD, UNITEXPORT.TYPE
    from EXPORTDATA, MODEL, MODELUNIT,
    UNITEXPORT
    WHERE ( ( MODELUNIT.MODEL = MODEL.MODEL )
    AND ( UNITEXPORT.UNIT =  MODELUNIT.UNIT)
    AND ( EXPORTDATA.EXPORTDATA =   UNITEXPORT.EXPORTDATA)  ) WITH READ ONLY
/

-- new version in Schema 2.6
create or replace view V_UNIT_TEXTURE_IMAGE as 
	select distinct UNIT.UNIT, UNITVERSION.UNITVERSION, IMAGE.IMAGE 
	from UNIT, UNITVERSION, OBJECT, ELEMENTCOMPLEX, ELEMENT, TEXTURE, IMAGE 
	where 
		UNITVERSION.UNIT = UNIT.UNIT and 
		OBJECT.UNITVERSION = UNITVERSION.UNITVERSION and 
		ELEMENTCOMPLEX.OBJECT = OBJECT.OBJECT and 
		ELEMENT.ELEMENTCOMPLEX = ELEMENTCOMPLEX.ELEMENTCOMPLEX and 
		TEXTURE.ELEMENT = ELEMENT.ELEMENT and 
		IMAGE.IMAGE = TEXTURE.IMAGE
/

-- new views in schema 4.2
create or replace view V_LAST_GEOM_VERSIONNUMBER as 
	select UNITVERSION.UNIT, max(UNITVERSION.VERSIONNUMBER) as VERSIONNUMBER 
	from UNITVERSION 
	where UNITVERSION.STATE in (1,2) 
	group by UNITVERSION.UNIT;
/

create or replace view V_LAST_GEOM_VERSION as 
	select UNITVERSION.UNITVERSION, UNITVERSION.VERSIONNUMBER, UNITVERSION.VERSIONDATE, UNITVERSION.UNIT, UNITVERSION.STATE, UNITVERSION."COMMENT" 
	from UNITVERSION, V_LAST_GEOM_VERSIONNUMBER 
	where UNITVERSION.UNIT=V_LAST_GEOM_VERSIONNUMBER.UNIT 
	and UNITVERSION.VERSIONNUMBER=V_LAST_GEOM_VERSIONNUMBER.VERSIONNUMBER;
/
